# coding: utf-8

"""
FilesApi.py
Copyright 2015 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class FilesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def files_fileidentifier_get(self, fileidentifier, **kwargs):
        """
        get file based on uuid
        Get file based on uuid.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.files_fileidentifier_get(fileidentifier, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str fileidentifier: uuid of a file as provided when you originally stored it. (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['fileidentifier']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method files_fileidentifier_get" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'fileidentifier' is set
        if ('fileidentifier' not in params) or (params['fileidentifier'] is None):
            raise ValueError("Missing the required parameter `fileidentifier` when calling `files_fileidentifier_get`")

        resource_path = '/files/{fileidentifier}'.replace('{format}', 'json')
        method = 'GET'

        path_params = {}
        if 'fileidentifier' in params:
            path_params['fileidentifier'] = params['fileidentifier']

        query_params = {}

        header_params = {}

        form_params = {}
        files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'application/x-gzip'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = []

        response = self.api_client.call_api(resource_path, method,
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=files,
                                            response_type='InlineResponse200',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def files_fileidentifier_put(self, fileidentifier, **kwargs):
        """
        put file based on filename
        Put file based on filename, returns the uuid of the stored file.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.files_fileidentifier_put(fileidentifier, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str fileidentifier: filename of the file you want to store (required)
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['fileidentifier']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method files_fileidentifier_put" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'fileidentifier' is set
        if ('fileidentifier' not in params) or (params['fileidentifier'] is None):
            raise ValueError("Missing the required parameter `fileidentifier` when calling `files_fileidentifier_put`")

        resource_path = '/files/{fileidentifier}'.replace('{format}', 'json')
        method = 'PUT'

        path_params = {}
        if 'fileidentifier' in params:
            path_params['fileidentifier'] = params['fileidentifier']

        query_params = {}

        header_params = {}

        form_params = {}
        files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'application/x-gzip'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = []

        response = self.api_client.call_api(resource_path, method,
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=files,
                                            response_type='InlineResponse200',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def files_fileidentifier_delete(self, fileidentifier, **kwargs):
        """
        delete file based on uuid
        Put file based on filename, returns the uuid of the stored file.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.files_fileidentifier_delete(fileidentifier, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str fileidentifier: filename identifier of the file you wish to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['fileidentifier']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method files_fileidentifier_delete" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'fileidentifier' is set
        if ('fileidentifier' not in params) or (params['fileidentifier'] is None):
            raise ValueError("Missing the required parameter `fileidentifier` when calling `files_fileidentifier_delete`")

        resource_path = '/files/{fileidentifier}'.replace('{format}', 'json')
        method = 'DELETE'

        path_params = {}
        if 'fileidentifier' in params:
            path_params['fileidentifier'] = params['fileidentifier']

        query_params = {}

        header_params = {}

        form_params = {}
        files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json', 'application/x-gzip'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = []

        response = self.api_client.call_api(resource_path, method,
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response
